"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LANGS = void 0;
exports.disposeHighlighter = disposeHighlighter;
exports.getHighlighter = getHighlighter;
exports.getSafeLanguage = getSafeLanguage;
exports.isValidLanguage = isValidLanguage;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _css = _interopRequireDefault(require("shiki/dist/langs/css.mjs"));
var _html = _interopRequireDefault(require("shiki/dist/langs/html.mjs"));
var _javascript = _interopRequireDefault(require("shiki/dist/langs/javascript.mjs"));
var _json = _interopRequireDefault(require("shiki/dist/langs/json.mjs"));
var _markdown = _interopRequireDefault(require("shiki/dist/langs/markdown.mjs"));
var _php = _interopRequireDefault(require("shiki/dist/langs/php.mjs"));
var _tsx = _interopRequireDefault(require("shiki/dist/langs/tsx.mjs"));
var _typescript = _interopRequireDefault(require("shiki/dist/langs/typescript.mjs"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}

// Properly type and structure language definitions

// Map of all available languages with their implementations
const LANGS = exports.LANGS = {
  typescript: _typescript.default,
  javascript: _javascript.default,
  json: _json.default,
  html: _html.default,
  css: _css.default,
  markdown: _markdown.default,
  tsx: _tsx.default,
  php: _php.default,
  // Add a plaintext fallback
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};
let highlighterInstance = null;
async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Initialize the JavaScript regex engine
    log('Initializing JavaScript regex engine...');
    const engine = (0, _engineJavascript.createJavaScriptRegexEngine)();
    log('Engine created successfully');

    // Prepare languages for loading
    log('Loading language definitions...');
    const languageDefinitions = Object.values(LANGS);
    log(`Prepared ${languageDefinitions.length} language definitions`);

    // Create the highlighter core with static language definitions
    log('Creating highlighter core...');
    highlighterInstance = await (0, _core.createHighlighterCore)({
      langs: languageDefinitions,
      engine
    });
    log('Highlighter core created successfully');
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    throw new Error(`Failed to initialize syntax highlighter: ${error instanceof Error ? error.message : 'Unknown error'}`);
  }
}

// Clean up function
function disposeHighlighter() {
  if (highlighterInstance) {
    log('Disposing highlighter instance');
    highlighterInstance.dispose();
    highlighterInstance = null;
  }
}

// Helper function to validate language
function isValidLanguage(lang) {
  return lang in LANGS;
}

// Helper function to get safe language
function getSafeLanguage(lang) {
  return isValidLanguage(lang) ? lang : 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map