"use strict";

/* eslint-disable no-console */
import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import css from 'shiki/dist/langs/css.mjs';
import html from 'shiki/dist/langs/html.mjs';
import javascript from 'shiki/dist/langs/javascript.mjs';
import json from 'shiki/dist/langs/json.mjs';
import markdown from 'shiki/dist/langs/markdown.mjs';
import php from 'shiki/dist/langs/php.mjs';
import tsx from 'shiki/dist/langs/tsx.mjs';
import typescript from 'shiki/dist/langs/typescript.mjs';
const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}

// Properly type and structure language definitions

// Map of all available languages with their implementations
export const LANGS = {
  typescript,
  javascript,
  json,
  html,
  css,
  markdown,
  tsx,
  php,
  // Add a plaintext fallback
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};
let highlighterInstance = null;
export async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Initialize the JavaScript regex engine
    log('Initializing JavaScript regex engine...');
    const engine = createJavaScriptRegexEngine();
    log('Engine created successfully');

    // Prepare languages for loading
    log('Loading language definitions...');
    const languageDefinitions = Object.values(LANGS);
    log(`Prepared ${languageDefinitions.length} language definitions`);

    // Create the highlighter core with static language definitions
    log('Creating highlighter core...');
    highlighterInstance = await createHighlighterCore({
      langs: languageDefinitions,
      engine
    });
    log('Highlighter core created successfully');
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    throw new Error(`Failed to initialize syntax highlighter: ${error instanceof Error ? error.message : 'Unknown error'}`);
  }
}

// Clean up function
export function disposeHighlighter() {
  if (highlighterInstance) {
    log('Disposing highlighter instance');
    highlighterInstance.dispose();
    highlighterInstance = null;
  }
}

// Helper function to validate language
export function isValidLanguage(lang) {
  return lang in LANGS;
}

// Helper function to get safe language
export function getSafeLanguage(lang) {
  return isValidLanguage(lang) ? lang : 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map